@@ -93,8 +93,8 @@ main (int argc, char *argv[])
 	}
 
 	// initialize Measurement (Projekt)
-	m_functions = {_("Time"),_("Wavelength"),_("DC Voltage"),_("AC Voltage"),_("DC Current"),_("AC Current"),
-	_("Resistance"),_("Conductivity"),_("pH"),_("Temperature"),_("Absorption")};
+	m_functions = {_("Time"),_("DC Voltage"),_("AC Voltage"),_("DC Current"),_("AC Current"),
+	_("Resistance"),_("Conductivity"),_("pH"),_("Temperature")};
 	acid = {
 	{_("Hydrochloric acid"),1,-6.0},
 	{_("Hydrobromic acid"),1,-6.0},
@@ -185,11 +185,11 @@ main (int argc, char *argv[])
 	builder->get_widget("menu_export_diag", menu_export_diag);
 	menu_export_diag->signal_activate().connect(sigc::ptr_fun(export_diag));
 	builder->get_widget("menu_options_diag", menu_options_diag);
-	menu_options_diag->signal_activate().connect(sigc::ptr_fun(set_options_diag));
+	menu_options_diag->signal_activate().connect(sigc::ptr_fun(show_options_diag));
 	builder->get_widget("menu_options_deviceX", menu_options_deviceX);
-	menu_options_deviceX->signal_activate().connect(sigc::ptr_fun(set_options_device_x));
+	menu_options_deviceX->signal_activate().connect(sigc::ptr_fun(show_options_device_x));
 	builder->get_widget("menu_options_deviceY", menu_options_deviceY);
-	menu_options_deviceY->signal_activate().connect(sigc::ptr_fun(set_options_device_y));
+	menu_options_deviceY->signal_activate().connect(sigc::ptr_fun(show_options_device_y));
 	builder->get_widget("menu_options_save", menu_options_save);
 	menu_options_save->signal_activate().connect(sigc::ptr_fun(save_all_options));
 	builder->get_widget("menu_options_load", menu_options_load);
@@ -403,6 +403,8 @@ main (int argc, char *argv[])
 	// Recall options if dmm_typ changed
 	dmm_typ[0]->signal_changed().connect(sigc::ptr_fun(restart_options_x));
 	dmm_typ[1]->signal_changed().connect(sigc::ptr_fun(restart_options_y));
+	dmm_timeout[0]->signal_changed().connect(sigc::ptr_fun(preset_mtime));
+	dmm_timeout[1]->signal_changed().connect(sigc::ptr_fun(preset_mtime));
 	dmm_name[0]->signal_changed().connect(sigc::bind<int>(sigc::ptr_fun(select_dmm), 0));
 	dmm_name[1]->signal_changed().connect(sigc::bind<int>(sigc::ptr_fun(select_dmm), 1));
 	//Show serial options for dmm if RS232C
@@ -434,7 +436,50 @@ main (int argc, char *argv[])
 	// Change range options, if function changed
 	dmm_funktion[0]->signal_changed().connect(sigc::bind<int>(sigc::ptr_fun(set_range_options_device), 0));
 	dmm_funktion[1]->signal_changed().connect(sigc::bind<int>(sigc::ptr_fun(set_range_options_device), 1));
-	
+	//simulation parameter
+	dmm_simtyp[0]->signal_changed().connect(sigc::bind<int>(sigc::ptr_fun(show_simulation_options), 0));
+	dmm_simtyp[1]->signal_changed().connect(sigc::bind<int>(sigc::ptr_fun(show_simulation_options), 1));
+	//linear
+	builder->get_widget("sim1_linoptions", sim_linoptions[0]);
+	builder->get_widget("sim1_slope_switch", sim_slope_switch[0]);
+	builder->get_widget("sim1_slope", sim_slope[0]);
+	builder->get_widget("sim2_linoptions", sim_linoptions[1]);
+	builder->get_widget("sim2_slope_switch", sim_slope_switch[1]);
+	builder->get_widget("sim2_slope", sim_slope[1]);
+	sim_slope_switch[0]->signal_state_flags_changed().connect(sigc::bind<int>(sigc::ptr_fun(show_simlin_options), 0));
+	sim_slope_switch[1]->signal_state_flags_changed().connect(sigc::bind<int>(sigc::ptr_fun(show_simlin_options), 1));
+	builder->get_widget("sim1_shift_switch", sim_shift_switch[0]);
+	builder->get_widget("sim2_shift_switch", sim_shift_switch[1]);
+	builder->get_widget("sim1_shift", sim_shift[0]);
+	builder->get_widget("sim2_shift", sim_shift[1]);
+	sim_shift_switch[0]->signal_state_flags_changed().connect(sigc::bind<int>(sigc::ptr_fun(show_simlin_options), 0));
+	sim_shift_switch[1]->signal_state_flags_changed().connect(sigc::bind<int>(sigc::ptr_fun(show_simlin_options), 1));
+	//exponential
+	builder->get_widget("sim2_exp_options", sim_expoptions);
+	builder->get_widget("sim2_init_sw", sim_init_sw);
+	builder->get_widget("sim2_tc_sw", sim_tc_sw);
+	builder->get_widget("sim2_expshift_sw", sim_expshift_sw);
+	builder->get_widget("sim2_init", sim_init);
+	builder->get_widget("sim2_tc", sim_tc);
+	builder->get_widget("sim2_expshift", sim_expshift);
+	sim_init_sw->signal_state_flags_changed().connect(sigc::ptr_fun(show_simexp_options));
+	sim_tc_sw->signal_state_changed().connect(sigc::ptr_fun(show_simexp_options));
+	sim_expshift_sw->signal_state_changed().connect(sigc::ptr_fun(show_simexp_options));
+	//peak
+	builder->get_widget("sim2_chrom_options", sim_chromoptions);
+	builder->get_widget("sim2_np_sw", sim_np_sw);
+	builder->get_widget("sim2_max_rt_sw", sim_max_rt_sw);
+	builder->get_widget("sim2_bf_sw", sim_bf_sw);
+	builder->get_widget("sim2_drift_sw", sim_drift_sw);
+	builder->get_widget("sim2_np", sim_np);
+	builder->get_widget("sim2_max_rt", sim_max_rt);
+	builder->get_widget("sim2_bf", sim_bf);
+	builder->get_widget("sim2_drift", sim_drift);
+	sim_np_sw->signal_state_flags_changed().connect(sigc::ptr_fun(show_simchrom_options));
+	sim_max_rt_sw->signal_state_flags_changed().connect(sigc::ptr_fun(show_simchrom_options));
+	sim_bf_sw->signal_state_flags_changed().connect(sigc::ptr_fun(show_simchrom_options));
+	sim_drift_sw->signal_state_flags_changed().connect(sigc::ptr_fun(show_simchrom_options));
+		
 
 	//UI eval
 	try
