@@ -43,7 +43,7 @@ using namespace std;
 
 //////////////// Multimeter /////////////////////////
 
-Multimeter::Multimeter ()	//Standard: Digitalmultimeter mit Standardwerten
+Multimeter::Multimeter ()	// DMM with standard values 
 {
 	dmm_name = "";
 	int_face = "";
@@ -58,7 +58,7 @@ Multimeter::Multimeter ()	//Standard: Digitalmultimeter mit Standardwerten
 	usb = false;
 	num_bytes = 0;
 	num_val = 1;
-	ms_timeout = 100;
+	ms_timeout = 1000;
 	m_funkt = _("DC Voltage");
 	m_range = "2 V";
 	remote_cfg = false;
@@ -71,7 +71,7 @@ Multimeter::Multimeter ()	//Standard: Digitalmultimeter mit Standardwerten
 	remote_ctrl_strings [6] = {Res, ""};
 	remote_ctrl_strings [7] = {Cond, ""};
 	remote_ctrl_strings [8] = {pH, ""};
-	remote_ctrl_strings [9] = {Temp, ""};	
+	remote_ctrl_strings [9] = {Temp, ""};
 }
 
 Multimeter::~Multimeter ()
@@ -110,7 +110,7 @@ std::string Multimeter::get_ctrlstr (mfkt funktion)
 int Multimeter::random_nr (int min, int max)
 {
 	int	rand_nr;
-	
+
 	rand_nr = rand() % max + min;
 	return rand_nr;
 }
@@ -142,17 +142,21 @@ void Multimeter::connect_dmm (std::string int_face)
 	if ((dmm_typ != DMM) && (dmm_typ != DEVICE))	//simulation
 	{
 		srand (time(NULL));
-		m = 0.1 * random_nr (1, 10);
-		a = 0.1 * random_nr (1, 10);
-		k = 0.01 * random_nr (1, 10);
-		n = random_nr(5, 20);
-		for (int i=0;i<=n;i++)
+		if (auto_slope) m = 0.1 * random_nr (1, 10); // set standard slope 1
+		if (auto_shift) rf = 0.02; // set standard deviation 2% of slope
+		if (auto_rt) max_rt = 180; // set maximum retention time for peaks
+		if (auto_bf) bf = 0.005; // set peak width factor
+		if (auto_expshift) exp_rf = 0.01;
+		if (auto_init) a = 0.1 * random_nr (1, 10);
+		if (auto_tc) k = 0.01 * random_nr (1, 10);
+		if (auto_np) n = random_nr(3, 20);
+		for (int i=0;i<n;i++)
 		{
-			P[i] = 0.00001 * random_nr (1, 10000);
-			rt[i] = random_nr (1, 180);
-			b[i] = 0.005 * random_nr (1, 100);
+			P[i] = 0.001 * random_nr (5, 100);
+			rt[i] = random_nr (1, max_rt);
+			b[i] = bf * random_nr (1, 100);
 		}
-		drift = 0.000005 * random_nr (0, 10);
+		if (auto_drift) drift = 0.000005 * random_nr (0, 10);
 		if (dmm_typ == PH)
 		{
 			set_tit_data (ha.npks);
@@ -348,21 +352,27 @@ void Multimeter::setup (std::string funkt, std::string range)
 
 double Multimeter::sim_linear (double x)
 {
-	double result, r;
+	double result, r, sign;
 	
 	srand (time(NULL));
-	r = 0.02 * random_nr (1, 10);
-	result = m * x + r;
+	sign = random_nr (1,2);
+	if (sign == 2) sign = -1;
+	result = m * x;
+	r = sign * 0.1 * random_nr (1,10) * rf * m; //effective shift in percent
+	result = result + r;
 	return result;
 }
 
 double Multimeter::sim_exp (double x)
 {
-	double result, r;
+	double result, r, sign;
 
 	srand (time(NULL));
-	r = 0.001 * random_nr (1, 10);
-	result = a * exp (-k * x) + r;
+	sign = random_nr (1,2);
+	if (sign == 2) sign = -1;
+	result = a * exp (-k * x);
+	r = sign *  0.1 * random_nr (1,10) * exp_rf * result;	//effective shift in percent
+	result = result + r;
 	return result;
 }
 
@@ -422,7 +432,7 @@ double Multimeter::sim_peak (double x)
 
 	result = 0;
 	// Gauss-Funktion
-	for (int i=0;i<=n;i++)
+	for (int i=0;i<n;i++)
 	{
 		result = result + P[i] * exp(-0.5 * pow((x - rt[i])/b[i],2));
 	}
@@ -431,21 +441,6 @@ double Multimeter::sim_peak (double x)
 }
 
 
-double Multimeter::sim_spekt (double x)
-{
-	double result;
-
-	result = 0;
-	// Lorentz-Funktion
-	for (int i=0;i<=n;i++)	
-	{
-		result = result + 5*P[i] * 1 / (1 + pow((x - rt[i]),2) / 5*b[i]);
-	}
-		
-	
-	return result;
-}
-
 m_record Multimeter::get_mwert_dmm (std::string mwert)	// Voltcraft, Metex and others
 {
 	m_record messw;
@@ -717,11 +712,6 @@ m_record Multimeter::read_dmm ()
 		case PEAK:
 			messw.digits = sim_peak(mt);
 			break;
-		case SPEKTRUM:
-			messw.digits = sim_spekt(mt);
-			messw.funktion = _("Absorption");
-			messw.unit = _("Intensity");
-			break;
 		case DEVICE:
 			messw = read_device();
 			break;
@@ -1078,9 +1068,10 @@ void Diagramm::set_coord_limits ()		//set limits for coordinate system
 	else if (dy<5.0) dy= 5.0;
 	else if (dy<10.0) dy= 10.0;
 	dy *= pow(10,exp);
-	yscale = 10.0 * dy;
 	ymin = floor(ymin/dy)*dy;
+	yscale = 10.0 * dy;
 	ymax = ymin + yscale;
+			
 	if (funktion_y == "pH") 
 	{
 		ymin = 0.0;
@@ -1102,13 +1093,6 @@ void Diagramm::set_coord_limits ()		//set limits for coordinate system
 	xmin = floor(xmin/dx)*dx;
 	xmax = xmin + xscale;
 
-	if (funktion_x == _("Wavelength")) 
-	{
-		xmin = 400.0;
-		xmax = 800.0;
-		xscale = 400.0;
-	}
-		
 	return;
 }
 
@@ -1379,11 +1363,11 @@ void Diagramm::draw_lin_regression(const Cairo::RefPtr<Cairo::Context> &ct)
 	
 	ct->set_source_rgb(funktcol_r, funktcol_g, funktcol_b);
     ct->set_line_width(ps*scalefactor);
-	y = mw_axis + mw_slope * xmin;
+	y = mw_axis + mw_slope * xmin/xrange;
 	px = pxmin;
 	py = scale_y(yrange*y);
 	ct->move_to(px,py);
-	y = mw_axis + mw_slope * xmax;	
+	y = mw_axis + mw_slope * xmax/xrange;	
 	px = pxmax;
 	py = scale_y(yrange*y);
 	ct->line_to (px,py);
@@ -1808,7 +1792,7 @@ void Diagramm::set_unit()
 			unit_x = upgrade_unit (unit_x);
 		}
 	}	
-	else if (funktion_x != _("Wavelength"))
+	else
 	{
 		while ((xrange*xabsmax < 0.001) && (xabsmax != 0) && (unit_x.at(0) != 'p'))
 		{
@@ -1822,7 +1806,7 @@ void Diagramm::set_unit()
 		}
 	}
 	//set unit for y values
-	if ((funktion_y != "pH") && (funktion_y != _("Temperature")) && (funktion_y != _("Absorption")))
+	if ((funktion_y != "pH") && (funktion_y != _("Temperature")))
 	{
 		while ((yrange*yabsmax < 0.001) && (yabsmax != 0) && (unit_y.at(0) != 'p'))
 		{
@@ -1934,7 +1918,6 @@ void show_settings_device_x ()
 	std::string function_x;
 
 	function_x = func_x->get_active_text();
-	//if (dmm[0].dmm_typ == TIME)
 	if (function_x == _("Time"))
 	{
 		device_x->hide();
@@ -1973,15 +1956,19 @@ void show_settings_device_y ()
 			device_y->set_label (_("Simulation (pH)"));
 			tit_options->show();
 		}
-		else if (dmm[1].dmm_typ == PEAK) device_y->set_label (_("Simulation (chromatogramm)"));
-		else if (dmm[1].dmm_typ == SPEKTRUM) device_y->set_label (_("Simulation (spectrum)"));
+		else if (dmm[1].dmm_typ == PEAK) device_y->set_label (_("Simulation (chromatogram)"));
 		device_y->show();
 	}
 }
 
 void configure_settings_device_x()
 {
-	set_options_device_x();
+	std::string option;
+	
+	set_messfunkt (0, func_x->get_active_text());
+	option = device_x->get_label ();
+	if (option == _("Simulation (linear)"))	dmm[0].dmm_typ = LINEAR;
+	show_options_device_x();
 	func_x->set_active_text (project->funktion_x);
 	show_settings_device_x ();
 	projekt_prop->queue_draw ();
@@ -1989,7 +1976,8 @@ void configure_settings_device_x()
 
 void configure_settings_device_y()
 {
-	set_options_device_y();
+	set_messfunkt (1, func_y->get_active_text());
+	show_options_device_y();
 	func_y->set_active_text (project->funktion_y);
 	show_settings_device_y ();
 	projekt_prop->queue_draw ();
@@ -1997,14 +1985,15 @@ void configure_settings_device_y()
 
 void define_project ()
 {
-	std::string error_str;
+	std::string error_str, profun_x, profun_y;
+	typ dmm1_typ,dmm2_typ;
 		
+	//save actual settings
+	profun_x = project->funktion_x;
+	profun_y = project->funktion_y;
+	dmm1_typ = dmm[0].dmm_typ;
+	dmm2_typ = dmm[1].dmm_typ;
 	projekt_title->set_text (project->title);
-	if (dmm[1].dmm_typ == SPEKTRUM)
-	{
-		func_x->append (project->funktion_x);
-		func_y->append (project->funktion_y);
-	}
 	func_x->set_active_text (project->funktion_x);
 	func_y->set_active_text (project->funktion_y);
 	show_settings_device_x ();
@@ -2063,6 +2052,11 @@ void define_project ()
     	case(Gtk::RESPONSE_CANCEL):
     	{
 			projekt_prop->hide();
+			//reset project settings 
+			project->funktion_x = profun_x;
+			project->funktion_y = profun_y;
+			dmm[0].dmm_typ = dmm1_typ;
+			dmm[1].dmm_typ = dmm2_typ;
 			return;
 			break;
     	}
@@ -2116,13 +2110,13 @@ void show_tit_options()
 
 void set_messfunkt (int kanal, std::string funkt)
 {
+	std::string dmm_typ;
+
 	if (kanal == 0) project->funktion_x = funkt;
 	else project->funktion_y = funkt;
 	dmm[kanal].m_funkt = funkt;
-	if (dmm[kanal].dmm_name == _("Simulation"))
-	{
-		if (funkt == "pH") dmm[kanal].dmm_typ = PH;
-	}
+	if (funkt == _("Time")) dmm[kanal].dmm_typ = TIME;
+	
 	return;
 }
 
@@ -2138,8 +2132,6 @@ std::string set_std_unit (std::string funkt)	// set standard unit
 	else if (funkt == _("Conductivity")) unit = "S";
 	else if (funkt == "pH") unit = "pH";
 	else if (funkt == _("Temperature")) unit = "°C";
-	else if (funkt == _("Wavelength")) unit = "nm";
-	else if (funkt == _("Absorption")) unit = _("Intensity");
 	else unit = "?";
 	return unit;
 }
@@ -2155,8 +2147,6 @@ std::string set_std_range (std::string funkt)	// set standard range
 	else if (funkt == _("Conductivity")) range = "200 mS";
 	else if (funkt == _("pH")) range = "pH";
 	else if (funkt == _("Temperature")) range = "°C";
-	else if (funkt == _("Wavelength")) range = "400 - 800 nm";
-	else if (funkt == _("Absorption")) range = "1";
 	else range = "";
 	
 	return range;
@@ -2198,14 +2188,6 @@ void init_diag ()
 			diag->ymax = 14.0;
 			diag->dyax = 0.00714285714286;
 		}
-		else if (project->funktion_y == _("Absorption")) 
-		{
-			diag->yscale = 1.0;
-			diag->ymax = 1.0;
-			diag->xmin = 400;
-			diag->xmax = 800;
-			diag->xscale = 400.0;
-		}
 	}
 	return;
 }
@@ -2281,7 +2263,7 @@ void begin_mess()	//Prepare measurement
 	}
 	if ((dmm[1].dmm_typ == DMM) && (dmm[1].remote_cfg)) dmm[1].setup(dmm[1].m_funkt, dmm[1].m_range);
 	
-	if ((project->funktion_x != _("Time")) && (project->funktion_x != _("Wavelength")))
+	if ((project->funktion_x != _("Time")))
 	{
 		dmm[0].connect_dmm(dmm[0].int_face);	//Channel X-Values
 		if (!dmm[0].connected)
@@ -2295,14 +2277,9 @@ void begin_mess()	//Prepare measurement
 		}
 		if ( (dmm[0].dmm_typ == DMM) && (dmm[0].remote_cfg)) dmm[0].setup(dmm[0].m_funkt, dmm[0].m_range);
 	}
+	else project->unit_x = "s";
 	
-	else 
-	{
-		if (project->funktion_x == _("Wavelength")) project->unit_x = "nm";
-		else project->unit_x = "s";
-	}
-	if (project->funktion_y == _("Absorption")) project->unit_y = _("Intensity");
-	
+		
 	diag->queue_draw();
 	button_messung->hide();
 	button_start->show();
@@ -2499,13 +2476,6 @@ void get_val()
 		xmval.funktion = _("Time");
 		xmval.unit = project->unit_x;
 	}
-	else if (project->funktion_x == _("Wavelength")) 
-	{
-		xmval.digits = 400/180* mt + 400;
-		xmval.funktion = _("Wavelength");
-		xmval.unit = "nm";
-		if (xmval.digits > 800) stop_mess ();
-	}
 	else 
 	{
 		xmval = dmm[0].read_dmm();
