@@ -25,7 +25,7 @@
 
 namespace fs = std::experimental::filesystem;
 
-//DMM-Functions: Transform to Strings
+///////////////////////////////// DMM-Functions: Transform to Strings  ///////////////
 std::string Multimeter::get_baud()
 {
 	std::string baudrate;
@@ -100,7 +100,6 @@ std::string Multimeter::get_flowcontrol()
 	return flowcontrol;
 }
 
-
 void Multimeter::set_flowcontrol(std::string flowcontrol)
 {
 	if (flowcontrol == "hardware") dmm_flowcontrol = LibSerial::FlowControl::FLOW_CONTROL_HARDWARE;
@@ -109,7 +108,6 @@ void Multimeter::set_flowcontrol(std::string flowcontrol)
 	return;
 }
 
-
 std::string Multimeter::get_stopbits()
 {
 	std::string stopbits;
@@ -145,7 +143,6 @@ std::string Multimeter::get_parity()
 	return parity;
 }
 
-
 void Multimeter::set_parity(std::string parity)
 {
 	if (parity == "even") dmm_parity = LibSerial::Parity::PARITY_EVEN;
@@ -155,22 +152,33 @@ void Multimeter::set_parity(std::string parity)
 }
 
 
+//////////////////////////////// show options //////////////////////////////////
 
-void set_options ()
+void show_options_diag ()
+{
+	edit_options->set_current_page (0);
+	set_options();
+	return;
+}
+
+void show_options_device_x ()
+{
+	edit_options->set_current_page (1);
+	set_options();
+	return;
+}
+
+void show_options_device_y ()
+{
+	edit_options->set_current_page (2);
+	set_options();
+	return;
+}
+
+void show_diag_settings ()
 {
 	Gdk::RGBA color;
-	std::string option, funkt_x_saved;
-	typ dmm1_typ_saved, dmm2_typ_saved;
-	int i, opt_page;
 	
-	
-	//set standard values (for reset)
-	std_axcol.set_rgba(0.0,0.0,0.0);
-	std_gridcol.set_rgba(0.5,0.5,0.5);
-	std_bkcol.set_rgba(0.95,0.95,0.94);
-	std_xycol.set_rgba(1.0,0.0,0.0);
-
-	//////////////// Show Diagram Settings //////////////////////
 	//Colours
 	color.set_rgba(diag->bkcol_r, diag->bkcol_g, diag->bkcol_b);
 	diag_bkcolor->set_rgba(color);
@@ -209,296 +217,6 @@ void set_options ()
 	diag_ymin->set_value(diag->ymin);
 	diag_ymax->set_value(diag->ymax);
 	show_diag_manual_limits (diag_autoscalesw->get_state ());
-	
-	//////////////////////// Show Device Settings /////////////////////
-	// save starting values 
-	dmm1_typ_saved = dmm[0].dmm_typ;
-	dmm2_typ_saved = dmm[1].dmm_typ;
-	funkt_x_saved = project->funktion_x;
-
-	// Set minimum values for Measurement intervall
-	if ((dmm[1].dmm_typ == DMM) || (dmm[1].dmm_typ == DEVICE)) min_timeout = dmm[1].ms_timeout;
-	else min_timeout = 0.01;
-	if ((dmm[0].dmm_typ == DMM) && (dmm[0].ms_timeout > dmm[1].ms_timeout)) min_timeout = dmm[0].ms_timeout;
-	dmm_mtime->set_range (0.001 * min_timeout, 3600); 
-	show_options_Kanal_XY ();
-	///////////////////////////////////////////////////////////////////////
-		
-	options_dialog-> show ();
-		
-	//////////////////////	Accept Settings  ///////////////////////
-	int result = options_dialog->run();
-	switch(result)
-  	{
-    	case(Gtk::RESPONSE_ACCEPT):
-    	{
-			///////////////////// Diagram Settings ///////////////////
-			//Colours
-			color = diag_bkcolor->get_rgba();
-			diag->bkcol_r = color.get_red();
-			diag->bkcol_g = color.get_green();
-			diag->bkcol_b = color.get_blue();
-			color = diag_axcolor->get_rgba();
-			diag->axcol_r = color.get_red();
-			diag->axcol_g = color.get_green();
-			diag->axcol_b = color.get_blue();
-			color = diag_gridcolor->get_rgba();
-			diag->gridcol_r = color.get_red();
-			diag->gridcol_g = color.get_green();
-			diag->gridcol_b = color.get_blue();
-			color = diag_xycolor->get_rgba();
-			diag->xycol_r = color.get_red();
-			diag->xycol_g = color.get_green();
-			diag->xycol_b = color.get_blue();
-			//Switches
-			diag->grid = diag_gridsw->get_state();
-			diag->autoscale = diag_autoscalesw->get_state();
-			diag->showzero = diag_zerosw->get_state();
-			diag->showtitle = diag_titlesw->get_state();
-			//Symbols
-			option = diag_symbol->get_active_text();
-			if (option == _("cross")) 
-			{
-				diag->mw_symbol = cross;
-				diag_symbolstyle->set_active_text(_("outline"));
-			}
-			else if (option == _("square")) diag->mw_symbol = square;
-			else if (option == _("circle")) diag->mw_symbol = circle;
-			else if (option == _("diamond")) diag->mw_symbol = diamond;
-			else diag->mw_symbol = none;
-			diag->symw = diag_symw->get_value();
-			//Symbol style
-			option = diag_symbolstyle->get_active_text();
-			if (option == _("filled")) diag->symbol_filled = true;
-			else diag->symbol_filled = false;
-			//Line style
-			option = diag_linestyle->get_active_text();
-			if (option == _("dashed")) diag->mw_linestyle = dashed;
-			else if (option == _("dotted")) diag->mw_linestyle = pointed;
-			else diag->mw_linestyle = solid;
-			//Connection between points
-			option = diag_graph->get_active_text();
-			if (option == _("line"))
-			{
-				diag->mw_line = true;
-				diag->mw_curve = false;
-			}
-			else if (option == _("curve"))
-			{
-				diag->mw_line = false;
-				diag->mw_curve = true;
-			}
-			else
-			{
-				diag->mw_line = false;
-				diag->mw_curve = false;
-			}
-			//manual scaling
-			diag->xmin = diag_xmin->get_value();
-			if (diag->xmin < 0) diag->xmin = 0;
-			if (diag_xmax->get_value() > diag->xmin) diag->xmax = diag_xmax->get_value();
-			diag->xscale = diag->xmax - diag->xmin;
-			diag->ymin = diag_ymin->get_value();
-			if ((diag->showzero) && (diag->ymin > 0)) diag->ymin = 0;
-			if (diag_ymax->get_value() > diag->ymin) diag->ymax = diag_ymax->get_value();
-			if ((diag->showzero) && (diag->ymax < 0)) diag->ymax = 0;
-			diag->yscale = diag->ymax - diag->ymin;
-			
-			////////////////////////// DMM Settings ///////////////////
-			diag->mtime = trunc (1000 * dmm_mtime->get_value());
-			if (diag->mtime < min_timeout) diag->mtime = min_timeout;
-
-			for (int k=0; k<=1; k++)
-			{
-				option = dmm_typ[k]->get_active_text();
-				if (option == _("Time")) 
-				{
-					dmm[k].dmm_typ = TIME;
-					dmm[k].dmm_name = "";
-					project->funktion_x = _("Time");
-				}
-				else if (option == _("Simulation"))
-				{
-					if (k == 0)
-					{
-						dmm[k].dmm_typ = LINEAR;
-						dmm[k].dmm_name = "";
-					}
-					else
-					{
-						option = dmm_simtyp[k]->get_active_text();
-						if (option == _("Exponential")) dmm[k].dmm_typ = EXP;
-						else if (option == _("Chromatogramm")) dmm[k].dmm_typ = PEAK;
-						else if (option == _("Spektrum")) 
-						{
-							dmm[k].dmm_typ = SPEKTRUM;
-							set_messfunkt (0, _("Wavelength"));
-							set_messfunkt (1, _("Absorption"));
-						}
-						else if (option == "pH") 
-						{
-							dmm[k].dmm_typ = PH;
-							set_messfunkt (1, "pH");
-							eval_titvolumen = true;
-						}
-						else dmm[k].dmm_typ = LINEAR;
-						dmm[k].dmm_name = "";
-						dmm[k].remote_cfg = false;
-					}
-				}
-				else if (option == _("Device"))
-				{
-					dmm[k].dmm_typ = DEVICE;
-					dmm[k].dmm_name = device_name->get_active_text();
-					dmm[k].int_face = device_interface->get_active_text();
-					if (dmm[k].dmm_name == "Lutron PH-207") set_device_options_lutron_ph207 ();
-					// other Devices following
-				
-				}
-				else 
-				{
-					dmm[k].dmm_typ = DMM;
-					dmm[k].dmm_name = dmm_name[k]->get_active_text();
-					dmm[k].int_face = dmm_interface[k]->get_active_text();
-					dmm[k].set_baud (dmm_baud[k]->get_active_text());
-					dmm[k].set_charsize (dmm_bits[k]->get_active_text());
-					dmm[k].set_flowcontrol (dmm_flowcontrol[k]->get_active_text());
-					dmm[k].set_stopbits (dmm_stopbits[k]->get_active_text());
-					dmm[k].set_parity (dmm_parity[k]->get_active_text());
-					dmm[k].dmm_polling = dmm_polling[k]->get_state();
-					dmm[k].scpi = dmm_scpi[k]->get_state();
-					dmm[k].num_bytes = dmm_num_bytes[k]->get_value();
-					dmm[k].num_val = dmm_num_val[k]->get_value();
-					dmm[k].ms_timeout = dmm_timeout[k]->get_value();
-					dmm[k].remote_cfg = dmm_remote_control[k]->get_state();
-					if (dmm_remote_control[k]->get_state())
-					{
-						set_messfunkt (k, dmm_funktion[k]->get_active_text());
-						dmm[k].m_range = dmm_range[k]->get_active_text();
-						dmm[k].set_ctrlstr (DCV, dmm_DCV[k]->get_active_text ());
-						dmm[k].set_ctrlstr (ACV, dmm_ACV[k]->get_active_text ());
-						dmm[k].set_ctrlstr (DCmA, dmm_DCmA[k]->get_active_text ());
-						dmm[k].set_ctrlstr (ACmA, dmm_ACmA[k]->get_active_text ());
-						dmm[k].set_ctrlstr (DCA, dmm_DCA[k]->get_active_text ());
-						dmm[k].set_ctrlstr (ACA, dmm_ACA[k]->get_active_text ());
-						dmm[k].set_ctrlstr (Res, dmm_Res[k]->get_active_text ());
-						dmm[k].set_ctrlstr (Cond, dmm_Cond[k]->get_active_text ());
-						dmm[k].set_ctrlstr (pH, dmm_pH[k]->get_active_text ());
-						dmm[k].set_ctrlstr (Temp, dmm_Temp[k]->get_active_text ());
-					}
-
-					//edit existing dmm or install new one
-					if (dmm_exist (dmm_name[k]->get_active_text())) i = id; else i = ++mid;
-					idmm[i].dmm_name = dmm_name[k]->get_active_text();
-					idmm[i].set_baud (dmm_baud[k]->get_active_text());
-					idmm[i].set_charsize (dmm_bits[k]->get_active_text());
-					idmm[i].set_flowcontrol (dmm_flowcontrol[k]->get_active_text());
-					idmm[i].set_stopbits (dmm_stopbits[k]->get_active_text());
-					idmm[i].set_parity (dmm_parity[k]->get_active_text());
-					idmm[i].dmm_polling = dmm_polling[k]->get_state();
-					idmm[i].scpi = dmm_scpi[k]->get_state();
-					idmm[i].num_bytes = dmm_num_bytes[k]->get_value();
-					idmm[i].num_val = dmm_num_val[k]->get_value();
-					idmm[i].ms_timeout = dmm_timeout[k]->get_value();
-					idmm[i].remote_cfg = dmm_remote_control[k]->get_state();
-					if (dmm_remote_control[k]->get_state())
-					{
-						idmm[i].set_ctrlstr (DCV, dmm_DCV[k]->get_active_text ());
-						idmm[i].set_ctrlstr (ACV, dmm_ACV[k]->get_active_text ());
-						idmm[i].set_ctrlstr (DCmA, dmm_DCmA[k]->get_active_text ());
-						idmm[i].set_ctrlstr (ACmA, dmm_ACmA[k]->get_active_text ());
-						idmm[i].set_ctrlstr (DCA, dmm_DCA[k]->get_active_text ());
-						idmm[i].set_ctrlstr (ACA, dmm_ACA[k]->get_active_text ());
-						idmm[i].set_ctrlstr (Res, dmm_Res[k]->get_active_text ());
-						idmm[i].set_ctrlstr (Cond, dmm_Cond[k]->get_active_text ());
-						idmm[i].set_ctrlstr (pH, dmm_pH[k]->get_active_text ());
-						idmm[i].set_ctrlstr (Temp, dmm_Temp[k]->get_active_text ());
-					}
-				}
-			}
-			
-			break;
-    	}
-    	case(Gtk::RESPONSE_CANCEL):
-    	{
-			// reset dmm_typ
-			dmm[0].dmm_typ = dmm1_typ_saved;
-			dmm[1].dmm_typ = dmm2_typ_saved;
-			project->funktion_x = funkt_x_saved;
-			break;
-    	}
-		case(Gtk::RESPONSE_DELETE_EVENT):	//Reset
-    	{
-			if (!dialog_ok (_("Reset options of current page?"))) break;
-			opt_page = edit_options->get_current_page ();
-			switch (opt_page)
-			{
-				case 0:		// Reset Diagram Settings
-				{
-					//Colours
-					diag->bkcol_r = std_bkcol.get_red();
-					diag->bkcol_g = std_bkcol.get_green();
-					diag->bkcol_b = std_bkcol.get_blue();
-					diag->axcol_r = std_axcol.get_red();
-					diag->axcol_g = std_axcol.get_green();
-					diag->axcol_b = std_axcol.get_blue();
-					diag->gridcol_r = std_gridcol.get_red();
-					diag->gridcol_g = std_gridcol.get_green();
-					diag->gridcol_b = std_gridcol.get_blue();
-					diag->xycol_r = std_xycol.get_red();
-					diag->xycol_g = std_xycol.get_green();
-					diag->xycol_b = std_xycol.get_blue();
-					//Switches
-					diag->grid = true;
-					diag->autoscale = true;
-					diag->showzero = false;
-					diag->showtitle = true;
-					//Symbols
-					diag->mw_symbol = none;
-					diag->symbol_filled = false;
-					//Line style
-					diag->mw_linestyle = solid;
-					//Connection between points
-					diag->mw_line = true;
-										
-					break;
-				}
-				case 1:		// Reset DMM-Settings Channel X
-				{
-					project->funktion_x = _("Time");
-					dmm[0].dmm_name = "";
-					dmm[0].int_face = "";
-					dmm[0].dmm_typ = TIME;
-					break;
-				}
-				case 2:		// Reset DMM-Settings Channel Y
-				{
-					dmm[1].dmm_name = "";
-					dmm[1].int_face = "";
-					dmm[1].dmm_typ = DMM;
-					dmm[1].dmm_baud = LibSerial::BaudRate::BAUD_9600;
-					dmm[1].dmm_charsize = LibSerial::CharacterSize::CHAR_SIZE_7;
-					dmm[1].dmm_flowcontrol = LibSerial::FlowControl::FLOW_CONTROL_NONE;
-					dmm[1].dmm_stopbits = LibSerial::StopBits::STOP_BITS_2;
-					dmm[1].dmm_parity = LibSerial::Parity::PARITY_NONE;
-					dmm[1].dmm_polling = true;
-					dmm[1].scpi = false;
-					dmm[1].num_bytes = 0;
-					dmm[1].num_val = 1;
-					dmm[1].ms_timeout = 100;
-					dmm[1].m_funkt = _("DC Voltage");
-					dmm[1].m_range = "2 V";
-					diag->mtime = 1000;
-					break;
-				}				
-			}
-			
-			break;
-    	}
-  	}
-		
-	
-	options_dialog->hide();
 	return;
 }
 
@@ -531,22 +249,27 @@ void show_options_Kanal_XY ()
 	int i;
 	bool dmm_remote;
 
-	messintervall = 0.001 * diag->mtime;		//Measurement Intervall in Seconds
-	dmm_mtime->set_value(messintervall);
+	preset_mtime ();	// Set minimum values for Measurement intervall
 	for (int k=0; k<=1; k++)
 	{
-		if ((k==0) && ((project->funktion_x == _("Time")) || (project->funktion_x == _("Wavelength")))) 
+		if (dmm[k].dmm_typ == TIME) 
 		{
-			dmm_typ[0]->set_active_text(_("Time"));
-			dmm_dmm_options[0]->hide();
-			dmm_serial_options[0]->hide();
-			dmm_simtyp[0]->hide();
+			dmm_typ[k]->set_active_text(_("Time"));
+			dmm_dmm_options[k]->hide();
+			dmm_serial_options[k]->hide();
+			dmm_simtyp[k]->hide();
 			dmm_control_options[k]->hide();
 			dmm_function_control[k]->hide();
+			sim_linoptions[k]->hide();
+			sim_expoptions->hide();
+			sim_chromoptions->hide();
 		}
-		else if (dmm[k].dmm_typ == DMM)
+		else if (dmm[k].dmm_typ == DMM)		//DMM
 		{
 			dmm_dmm_options[k]->show();
+			sim_linoptions[k]->hide();
+			sim_expoptions->hide();
+			sim_chromoptions->hide();
 			if (k == 1) dmm_device_options->hide();
 			dmm_typ[k]->set_active_text(_("Digitalmultimeter"));
 			dmm_simtyp[k]->hide();
@@ -594,13 +317,16 @@ void show_options_Kanal_XY ()
 			}
 			else dmm_control_options[k]-> hide();
 		}
-		else if (dmm[k].dmm_typ == DEVICE)
+		else if (dmm[k].dmm_typ == DEVICE)		//Device
 		{
 			dmm_dmm_options[k]->hide();
 			dmm_serial_options[k]->hide();
 			dmm_control_options[k]->hide();
 			dmm_function_control[k]->hide();
 			dmm_simtyp[k]->hide();
+			sim_linoptions[k]->hide();
+			sim_expoptions->hide();
+			sim_chromoptions->hide();
 			if (k == 1) dmm_device_options->show();
 			dmm_typ[k]->set_active_text(_("Device"));
 			device_interface->remove_all();
@@ -611,28 +337,232 @@ void show_options_Kanal_XY ()
 			device_interface->set_active_text(dmm[k].int_face);
 			device_interface->show();
 		}
-		else	// simulation
+		else									//Simulation
 		{
+			dmm_typ[k]->set_active_text(_("Simulation"));
 			dmm_dmm_options[k]->hide();
 			dmm_device_options->hide();
 			dmm_serial_options[k]->hide();
 			dmm_control_options[k]->hide();
 			dmm_function_control[k]->hide();
-			dmm_typ[k]->set_active_text(_("Simulation"));
 			switch (dmm[k].dmm_typ)
 			{
 				case LINEAR: dmm_simtyp[k]->set_active_text(_("Linear")); break;
 				case EXP: dmm_simtyp[k]->set_active_text(_("Exponential")); break;
-				case PEAK: dmm_simtyp[k]->set_active_text(_("Chromatogramm")); break;
-				case SPEKTRUM: dmm_simtyp[k]->set_active_text(_("Spektrum")); break;
+				case PEAK: dmm_simtyp[k]->set_active_text(_("Chromatogram")); break;
 				case PH: dmm_simtyp[k]->set_active_text("pH"); break;
 			}
 			dmm_simtyp[k]->show();
+			show_simulation_options (k);			
 		}
 	}
 	return;
 }
 
+
+void show_simulation_options (int k)	//show options for linear simulation
+{
+	std::string option;
+	typ simtyp;
+	
+	option = dmm_simtyp[k]->get_active_text();
+	if (option == _("Linear")) simtyp = LINEAR;
+	else if (option == _("Exponential")) simtyp = EXP;
+	else if (option == _("Chromatogram")) simtyp = PEAK;
+	else simtyp = PH;
+	switch (simtyp)
+	{
+		case LINEAR: 
+		{
+			dmm_simtyp[k]->set_active_text(_("Linear"));
+			sim_slope[k]->set_value(dmm[k].m);
+			sim_shift[k]->set_value(100*dmm[k].rf); //shift in percentage
+			if (dmm[k].auto_slope) 	//slope
+			{
+				sim_slope_switch[k]->set_state(true);
+				sim_slope[k]->set_sensitive (false);
+			}
+			else
+			{
+				sim_slope_switch[k]->set_state(false);				
+				sim_slope[k]->set_sensitive (true);
+			}
+	
+			if (dmm[k].auto_shift) 	//shift factor
+			{
+				sim_shift_switch[k]->set_state(true);
+				sim_shift[k]->set_sensitive (false);
+			}
+			else
+			{
+				sim_shift_switch[k]->set_state(false);
+				sim_shift[k]->set_sensitive (true);
+			}
+			sim_linoptions[k]->show();
+			sim_expoptions->hide();
+			sim_chromoptions->hide ();
+		} break;
+		case EXP:
+		{
+			dmm_simtyp[k]->set_active_text(_("Exponential"));
+			sim_init->set_value(dmm[k].a);
+			sim_tc->set_value(dmm[k].k);
+			sim_expshift->set_value(100*dmm[k].exp_rf); //shift in percentage
+			if (dmm[k].auto_init) 	//initial value
+			{
+				sim_init_sw->set_state(true);
+				sim_init->set_sensitive (false);
+			}
+			else
+			{
+				sim_init_sw->set_state(false);
+				sim_init->set_sensitive (true);
+			}
+			if (dmm[k].auto_tc) 	//time constant
+			{
+				sim_tc_sw->set_state(true);
+				sim_tc->set_sensitive (false);
+			}
+			else
+			{
+				sim_tc_sw->set_state(false);
+				sim_tc->set_sensitive (true);
+			}
+			if (dmm[k].auto_expshift) 	//shift factor
+			{
+				sim_expshift_sw->set_state(true);
+				sim_expshift->set_sensitive (false);
+			}
+			else
+			{
+				sim_expshift_sw->set_state(false);
+				sim_expshift->set_sensitive (true);
+			}
+			sim_expoptions->show();
+			sim_linoptions[k]->hide();
+			sim_chromoptions->hide ();
+		} break;
+		case PEAK:
+		{
+			dmm_simtyp[k]->set_active_text(_("Chromatogram"));
+			sim_np->set_value(dmm[k].n);
+			sim_max_rt->set_value(dmm[k].max_rt);
+			sim_bf->set_value(dmm[k].bf);
+			sim_drift->set_value(100*dmm[k].drift); //drift in %
+			if (dmm[k].auto_np) 	//number of peaks
+			{
+				sim_np_sw->set_state(true);
+				sim_np->set_sensitive (false);
+			}
+			else
+			{
+				sim_np_sw->set_state(false);
+				sim_np->set_sensitive (true);
+			}
+			if (dmm[k].auto_rt) 	//max. retention time
+			{
+				sim_max_rt_sw->set_state(true);
+				sim_max_rt->set_sensitive (false);
+			}
+			else
+			{
+				sim_max_rt_sw->set_state(false);				
+				sim_max_rt->set_sensitive (true);
+			}
+			if (dmm[k].auto_bf) 	//peak width
+			{
+				sim_bf_sw->set_state(true);
+				sim_bf->set_sensitive (false);
+			}
+			else
+			{
+				sim_bf_sw->set_state(false);
+				sim_bf->set_sensitive (true);
+			}
+			if (dmm[k].auto_drift) 	//drift
+			{
+				sim_drift_sw->set_state(true);
+				sim_drift->set_sensitive (false);
+			}
+			else
+			{
+				sim_drift_sw->set_state(false);
+				sim_drift->set_sensitive (true);
+			}
+			sim_chromoptions->show ();
+			sim_linoptions[k]->hide();
+			sim_expoptions->hide();
+		} break;
+		case PH:
+		{
+			dmm_simtyp[k]->set_active_text("pH");
+			
+			sim_linoptions[k]->hide();
+			sim_expoptions->hide();
+			sim_chromoptions->hide ();
+		} break;
+	}
+	
+	return;
+}
+
+void show_simlin_options (bool state, int k) // show options for linear simulation
+{
+	bool autoslope_x, autoshift_x, autoslope_y, autoshift_y;
+
+	autoslope_x = sim_slope_switch[0]->get_state ();
+	autoshift_x = sim_shift_switch[0]->get_state ();
+	autoslope_y = sim_slope_switch[1]->get_state ();
+	autoshift_y = sim_shift_switch[1]->get_state ();
+	if (autoslope_x) sim_slope[0]->set_sensitive (false);
+	else sim_slope[0]->set_sensitive (true);
+	if (autoshift_x) sim_shift[0]->set_sensitive (false);
+	else sim_shift[0]->set_sensitive (true);
+	if (autoslope_y) sim_slope[1]->set_sensitive (false);
+	else sim_slope[1]->set_sensitive (true);
+	if (autoshift_y) sim_shift[1]->set_sensitive (false);
+	else sim_shift[1]->set_sensitive (true);
+	return;
+}
+
+void show_simexp_options (int k) // show options for exponential simulation
+{
+	bool auto_init, auto_tc, auto_shift;
+
+	auto_init = sim_init_sw->get_state ();
+	auto_shift = sim_expshift_sw->get_state ();
+	auto_tc = sim_tc_sw->get_state ();
+	if (auto_init) sim_init->set_sensitive (false);
+	else sim_init->set_sensitive (true);
+	if (auto_tc) sim_tc->set_sensitive (false);
+	else sim_tc->set_sensitive (true);
+	if (auto_shift) sim_expshift->set_sensitive (false);
+	else sim_expshift->set_sensitive (true);
+	
+	return;
+}
+
+void show_simchrom_options (int k) // show options for peak simulation (chromatogram)
+{
+	bool auto_np, auto_rt, auto_bf, auto_drift;
+
+	auto_np = sim_np_sw->get_state ();
+	auto_rt = sim_max_rt_sw->get_state ();
+	auto_bf = sim_bf_sw->get_state ();
+	auto_drift = sim_drift_sw->get_state ();
+	if (auto_np) sim_np->set_sensitive (false);
+	else sim_np->set_sensitive (true);
+	if (auto_rt) sim_max_rt->set_sensitive (false);
+	else sim_max_rt->set_sensitive (true);
+	if (auto_bf) sim_bf->set_sensitive (false);
+	else sim_bf->set_sensitive (true);
+	if (auto_drift) sim_drift->set_sensitive (false);
+	else sim_drift->set_sensitive (true);
+
+	return;
+}
+
+
 void show_dmm_control_options (bool state, int kanal)
 {
 	bool dmm_remote_ctrl;
@@ -653,7 +583,6 @@ void show_dmm_control_options (bool state, int kanal)
 }
 
 
-
 void show_dmm_function_control(bool state, int k)
 {
 	bool dmm_remote_ctrl;
@@ -678,28 +607,356 @@ void show_dmm_function_control(bool state, int k)
 	return;
 }
 
-
-void set_options_diag ()
+void show_dmm_interface_options(int kanal)
 {
-	edit_options->set_current_page (0);
-	set_options();
+	std::string interface;
+	interface = dmm_interface[kanal]->get_active_text();
+	if (interface.find ("tty")< interface.size())
+		dmm_serial_options[kanal]->show();
+	else dmm_serial_options[kanal]->hide();
 	return;
 }
 
-void set_options_device_x ()
+void preset_mtime ()	//preset measuring timeout according to device option
 {
-	edit_options->set_current_page (1);
-	set_options();
+	double dmm1_timeout,dmm2_timeout;
+	std::string dmm1_typ, dmm2_typ;
+	
+	dmm1_timeout = dmm_timeout[0]->get_value ();
+	dmm2_timeout = dmm_timeout[1]->get_value ();
+	dmm1_typ = dmm_typ[0]->get_active_text ();
+	dmm2_typ = dmm_typ[1]->get_active_text ();	
+	if (dmm2_typ != _("Simulation")) min_timeout = dmm2_timeout;
+	else min_timeout = 1;
+	if ((dmm1_typ == _("Digitalmultimeter")) && (dmm1_timeout > min_timeout)) min_timeout = dmm1_timeout;
+	dmm_mtime->set_range (0.001 * min_timeout, 3600);
+	messintervall = 0.001 * diag->mtime;		// measurement intervall in seconds
+	dmm_mtime->set_value(messintervall);
+	dmm_mtime->queue_draw();
 	return;
 }
 
-void set_options_device_y ()
+void restart_options_x ()
 {
-	edit_options->set_current_page (2);
-	set_options();
+	std::string option;
+	
+	option = dmm_typ[0]->get_active_text();
+	if (option == _("Time")) dmm[0].dmm_typ = TIME;
+	else if (option == _("Digitalmultimeter")) dmm[0].dmm_typ = DMM;
+	else 
+	{
+		dmm[0].dmm_typ = LINEAR;
+		dmm_simtyp[0]->set_active_text(_("Linear"));
+	}
+	
+	show_options_Kanal_XY ();
+	
 	return;
 }
 
+void restart_options_y ()
+{
+	std::string option;
+	typ dmmtyp;
+
+	dmmtyp = dmm[1].dmm_typ;
+	option = dmm_typ[1]->get_active_text();
+	if (option == _("Digitalmultimeter")) dmm[1].dmm_typ = DMM;
+	else if (option == _("Device")) dmm[1].dmm_typ = DEVICE;
+	else 
+	{
+		dmm[1].dmm_typ = LINEAR;
+		if ((dmmtyp != DMM) && (dmmtyp != DEVICE))  dmm[1].dmm_typ = dmmtyp;
+	}
+	
+	show_options_Kanal_XY ();
+	return;
+}
+
+
+//////////////////////////////// set options //////////////////////////////////
+
+void set_options ()
+{
+	std::string option, funkt_x_saved;
+	typ dmm1_typ_saved, dmm2_typ_saved;
+	int i, opt_page;
+		
+	// save starting values 
+	dmm1_typ_saved = dmm[0].dmm_typ;
+	dmm2_typ_saved = dmm[1].dmm_typ;
+	funkt_x_saved = project->funktion_x;
+	show_diag_settings();	//diagram settings
+	show_options_Kanal_XY ();	//device settings
+	options_dialog-> show ();	//start dialog
+		
+	//////////////////////	Accept Settings  ///////////////////////
+	int result = options_dialog->run();
+	switch(result)
+  	{
+    	case(Gtk::RESPONSE_ACCEPT):
+    	{
+			set_options_diag ();	//set new options for diagram
+			// device settings
+			set_device_options (0);	//set device options for channel X
+			set_device_options (1);	//set device options for channel Y
+			set_mtime ();
+			break;
+    	}
+    	case(Gtk::RESPONSE_CANCEL):
+    	{
+			// reset dmm_typ
+			dmm[0].dmm_typ = dmm1_typ_saved;
+			dmm[1].dmm_typ = dmm2_typ_saved;
+			project->funktion_x = funkt_x_saved;
+			break;
+    	}
+		case(Gtk::RESPONSE_DELETE_EVENT):	//Reset
+    	{
+			if (!dialog_ok (_("Reset options of current page?"))) break;
+			opt_page = edit_options->get_current_page ();
+			switch (opt_page)
+			{
+				case 0:		// Reset Diagram Settings
+					reset_options_diag ();										
+					break;
+				case 1:		// Reset DMM-Settings Channel X
+					reset_options_kanal_X();
+					break;
+				case 2:		// Reset DMM-Settings Channel Y
+					reset_options_kanal_Y();
+					break;
+			}
+			
+			break;
+    	}
+  	}
+		
+	options_dialog->hide();
+	return;
+}
+
+
+void set_options_diag ()	// Diagram Settings
+{
+	Gdk::RGBA color;
+	std::string option;
+	
+	//Colours
+	color = diag_bkcolor->get_rgba();
+	diag->bkcol_r = color.get_red();
+	diag->bkcol_g = color.get_green();
+	diag->bkcol_b = color.get_blue();
+	color = diag_axcolor->get_rgba();
+	diag->axcol_r = color.get_red();
+	diag->axcol_g = color.get_green();
+	diag->axcol_b = color.get_blue();
+	color = diag_gridcolor->get_rgba();
+	diag->gridcol_r = color.get_red();
+	diag->gridcol_g = color.get_green();
+	diag->gridcol_b = color.get_blue();
+	color = diag_xycolor->get_rgba();
+	diag->xycol_r = color.get_red();
+	diag->xycol_g = color.get_green();
+	diag->xycol_b = color.get_blue();
+	//Switches
+	diag->grid = diag_gridsw->get_state();
+	diag->autoscale = diag_autoscalesw->get_state();
+	diag->showzero = diag_zerosw->get_state();
+	diag->showtitle = diag_titlesw->get_state();
+	//Symbols
+	option = diag_symbol->get_active_text();
+	if (option == _("cross")) 
+	{
+		diag->mw_symbol = cross;
+		diag_symbolstyle->set_active_text(_("outline"));
+	}
+	else if (option == _("square")) diag->mw_symbol = square;
+	else if (option == _("circle")) diag->mw_symbol = circle;
+	else if (option == _("diamond")) diag->mw_symbol = diamond;
+	else diag->mw_symbol = none;
+	diag->symw = diag_symw->get_value();
+	//Symbol style
+	option = diag_symbolstyle->get_active_text();
+	if (option == _("filled")) diag->symbol_filled = true;
+	else diag->symbol_filled = false;
+	//Line style
+	option = diag_linestyle->get_active_text();
+	if (option == _("dashed")) diag->mw_linestyle = dashed;
+	else if (option == _("dotted")) diag->mw_linestyle = pointed;
+	else diag->mw_linestyle = solid;
+	//Connection between points
+	option = diag_graph->get_active_text();
+	if (option == _("line"))
+	{
+		diag->mw_line = true;
+		diag->mw_curve = false;
+	}
+	else if (option == _("curve"))
+	{
+		diag->mw_line = false;
+		diag->mw_curve = true;
+	}
+	else
+	{
+		diag->mw_line = false;
+		diag->mw_curve = false;
+	}
+	//manual scaling
+	diag->xmin = diag_xmin->get_value();
+	if (diag->xmin < 0) diag->xmin = 0;
+	if (diag_xmax->get_value() > diag->xmin) diag->xmax = diag_xmax->get_value();
+	diag->xscale = diag->xmax - diag->xmin;
+	diag->ymin = diag_ymin->get_value();
+	if ((diag->showzero) && (diag->ymin > 0)) diag->ymin = 0;
+	if (diag_ymax->get_value() > diag->ymin) diag->ymax = diag_ymax->get_value();
+	if ((diag->showzero) && (diag->ymax < 0)) diag->ymax = 0;
+	diag->yscale = diag->ymax - diag->ymin;
+	
+	return;
+}
+
+void set_device_options (int k)	//set options for channel X,Y
+{
+	std::string option;
+	int i;
+	
+	option = dmm_typ[k]->get_active_text();
+	if (option == _("Time")) 
+	{
+		dmm[k].dmm_typ = TIME;
+		dmm[k].dmm_name = "";
+		project->funktion_x = _("Time");
+	}
+	else if (option == _("Simulation"))		//simulation
+	{
+		dmm[k].remote_cfg = false;
+		dmm[k].dmm_name = "";
+		dmm[k].int_face = "";
+		option = dmm_simtyp[k]->get_active_text();
+		if (option == _("Exponential")) 
+		{
+			dmm[k].dmm_typ = EXP;
+			dmm[k].auto_init = sim_init_sw->get_state();
+			if (!dmm[k].auto_init) dmm[k].a = sim_init->get_value ();
+			dmm[k].auto_tc = sim_tc_sw->get_state();
+			if (!dmm[k].auto_tc) dmm[k].k = sim_tc->get_value ();
+			dmm[k].auto_expshift = sim_expshift_sw->get_state();
+			if (!dmm[k].auto_expshift) dmm[k].exp_rf = 0.01*sim_expshift->get_value (); //shift in percent
+		}
+		else if (option == _("Chromatogram"))
+		{
+			dmm[k].dmm_typ = PEAK;
+			dmm[k].auto_np = sim_np_sw->get_state();
+			if (!dmm[k].auto_np) dmm[k].n = sim_np->get_value ();
+			dmm[k].auto_rt = sim_max_rt_sw->get_state();
+			if (!dmm[k].auto_rt) dmm[k].max_rt = sim_max_rt->get_value ();
+			dmm[k].auto_bf = sim_bf_sw->get_state();
+			if (!dmm[k].auto_bf) dmm[k].bf = sim_bf->get_value ();
+			dmm[k].auto_drift = sim_drift_sw->get_state();
+			if (!dmm[k].auto_drift) dmm[k].drift = 0.01*sim_drift->get_value ();	//drift in %
+		}
+		else if (option == "pH") 
+		{
+			dmm[k].dmm_typ = PH;
+			set_messfunkt (1, "pH");
+			eval_titvolumen = true;
+		}
+		else 
+		{
+			dmm[k].dmm_typ = LINEAR;
+			dmm[k].auto_slope = sim_slope_switch[k]->get_state();
+			if (!dmm[k].auto_slope) dmm[k].m = sim_slope[k]->get_value ();
+			dmm[k].auto_shift = sim_shift_switch[k]->get_state();
+			if (!dmm[k].auto_shift) dmm[k].rf = 0.01*sim_shift[k]->get_value (); //shift in percent
+		}
+		if (dmm[k].connected) dmm[k].disconnect_dmm ();  // make changes happen
+	}
+	else if (option == _("Device"))		//device
+	{
+		dmm[k].dmm_typ = DEVICE;
+		dmm[k].dmm_name = device_name->get_active_text();
+		dmm[k].int_face = device_interface->get_active_text();
+		if (dmm[k].dmm_name == "Lutron PH-207") set_device_options_lutron_ph207 ();
+		// other devices following
+		
+	}
+	else 								//DMM
+	{
+		dmm[k].dmm_typ = DMM;
+		dmm[k].dmm_name = dmm_name[k]->get_active_text();
+		dmm[k].int_face = dmm_interface[k]->get_active_text();
+		dmm[k].set_baud (dmm_baud[k]->get_active_text());
+		dmm[k].set_charsize (dmm_bits[k]->get_active_text());
+		dmm[k].set_flowcontrol (dmm_flowcontrol[k]->get_active_text());
+		dmm[k].set_stopbits (dmm_stopbits[k]->get_active_text());
+		dmm[k].set_parity (dmm_parity[k]->get_active_text());
+		dmm[k].dmm_polling = dmm_polling[k]->get_state();
+		dmm[k].scpi = dmm_scpi[k]->get_state();
+		dmm[k].num_bytes = dmm_num_bytes[k]->get_value();
+		dmm[k].num_val = dmm_num_val[k]->get_value();
+		dmm[k].ms_timeout = dmm_timeout[k]->get_value();
+		dmm[k].remote_cfg = dmm_remote_control[k]->get_state();
+		if (dmm_remote_control[k]->get_state())
+		{
+			set_messfunkt (k, dmm_funktion[k]->get_active_text());
+			dmm[k].m_range = dmm_range[k]->get_active_text();
+			dmm[k].set_ctrlstr (DCV, dmm_DCV[k]->get_active_text ());
+			dmm[k].set_ctrlstr (ACV, dmm_ACV[k]->get_active_text ());
+			dmm[k].set_ctrlstr (DCmA, dmm_DCmA[k]->get_active_text ());
+			dmm[k].set_ctrlstr (ACmA, dmm_ACmA[k]->get_active_text ());
+			dmm[k].set_ctrlstr (DCA, dmm_DCA[k]->get_active_text ());
+			dmm[k].set_ctrlstr (ACA, dmm_ACA[k]->get_active_text ());
+			dmm[k].set_ctrlstr (Res, dmm_Res[k]->get_active_text ());
+			dmm[k].set_ctrlstr (Cond, dmm_Cond[k]->get_active_text ());
+			dmm[k].set_ctrlstr (pH, dmm_pH[k]->get_active_text ());
+			dmm[k].set_ctrlstr (Temp, dmm_Temp[k]->get_active_text ());
+		}
+
+		//edit existing dmm or install new one
+		if (dmm_exist (dmm_name[k]->get_active_text())) i = id; else i = ++mid;
+		idmm[i].dmm_name = dmm_name[k]->get_active_text();
+		idmm[i].set_baud (dmm_baud[k]->get_active_text());
+		idmm[i].set_charsize (dmm_bits[k]->get_active_text());
+		idmm[i].set_flowcontrol (dmm_flowcontrol[k]->get_active_text());
+		idmm[i].set_stopbits (dmm_stopbits[k]->get_active_text());
+		idmm[i].set_parity (dmm_parity[k]->get_active_text());
+		idmm[i].dmm_polling = dmm_polling[k]->get_state();
+		idmm[i].scpi = dmm_scpi[k]->get_state();
+		idmm[i].num_bytes = dmm_num_bytes[k]->get_value();
+		idmm[i].num_val = dmm_num_val[k]->get_value();
+		idmm[i].ms_timeout = dmm_timeout[k]->get_value();
+		idmm[i].remote_cfg = dmm_remote_control[k]->get_state();
+		if (dmm_remote_control[k]->get_state())
+		{
+			idmm[i].set_ctrlstr (DCV, dmm_DCV[k]->get_active_text ());
+			idmm[i].set_ctrlstr (ACV, dmm_ACV[k]->get_active_text ());
+			idmm[i].set_ctrlstr (DCmA, dmm_DCmA[k]->get_active_text ());
+			idmm[i].set_ctrlstr (ACmA, dmm_ACmA[k]->get_active_text ());
+			idmm[i].set_ctrlstr (DCA, dmm_DCA[k]->get_active_text ());
+			idmm[i].set_ctrlstr (ACA, dmm_ACA[k]->get_active_text ());
+			idmm[i].set_ctrlstr (Res, dmm_Res[k]->get_active_text ());
+			idmm[i].set_ctrlstr (Cond, dmm_Cond[k]->get_active_text ());
+			idmm[i].set_ctrlstr (pH, dmm_pH[k]->get_active_text ());
+			idmm[i].set_ctrlstr (Temp, dmm_Temp[k]->get_active_text ());
+		}
+	}
+	
+	return;
+}
+
+void set_mtime ()	//set measuring timeout according to selected device
+{
+	if ((dmm[1].dmm_typ == DMM) || (dmm[1].dmm_typ == DEVICE)) min_timeout = dmm[1].ms_timeout;
+	else min_timeout = 1;
+	if ((dmm[0].dmm_typ == DMM) && (dmm[0].ms_timeout > dmm[1].ms_timeout)) min_timeout = dmm[0].ms_timeout;
+	diag->mtime = trunc (1000 * dmm_mtime->get_value());
+	if (diag->mtime < min_timeout) diag->mtime = min_timeout;
+	
+	return;
+}
+
+
 void set_range_options_device (int k)
 {
 	std::string funkt;
@@ -751,78 +1008,6 @@ void set_range_options_device (int k)
 	return;
 }
 
-
-void show_dmm_interface_options(int kanal)
-{
-	std::string interface;
-	interface = dmm_interface[kanal]->get_active_text();
-	if (interface.find ("tty")< interface.size())
-		dmm_serial_options[kanal]->show();
-	else dmm_serial_options[kanal]->hide();
-	return;
-}
-
-
-void preset_mtime ()
-{
-	std::string dev;
-	
-	
-	dev = dmm_name[1]->get_active_text();
-	if (dev == "Lutron PH-207") min_timeout = 2000;
-	// other devices following
-	
-	else min_timeout = 1000;
-		
-	dmm_mtime->set_range (0.001 * min_timeout, 3600);
-	dmm_device_options->queue_draw();
-	return;
-}
-
-void restart_options_x ()
-{
-	std::string option;
-	typ dmmtyp;
-	std::string akt_funktion;
-
-	akt_funktion = project->funktion_x;
-	dmmtyp = dmm[0].dmm_typ;
-	option = dmm_typ[0]->get_active_text();
-	if (option == _("Time")) project->funktion_x = _("Time");
-	else 
-	{
-		if (akt_funktion == _("Time")) project->funktion_x = _("DC Voltage");
-		if (option == _("Digitalmultimeter")) dmm[0].dmm_typ = DMM;
-		else 
-		{
-			dmm[0].dmm_typ = LINEAR;
-			if ((dmmtyp != DMM) && (dmmtyp != DEVICE))  dmm[0].dmm_typ = dmmtyp;
-		}
-	}
-	show_options_Kanal_XY ();
-	return;
-}
-
-void restart_options_y ()
-{
-	std::string option;
-	typ dmmtyp;
-
-	dmmtyp = dmm[1].dmm_typ;
-	option = dmm_typ[1]->get_active_text();
-	if (option == _("Digitalmultimeter")) dmm[1].dmm_typ = DMM;
-	else if (option == _("Device")) dmm[1].dmm_typ = DEVICE;
-	else 
-	{
-		dmm[1].dmm_typ = LINEAR;
-		if ((dmmtyp != DMM) && (dmmtyp != DEVICE))  dmm[1].dmm_typ = dmmtyp;
-	}
-	
-	show_options_Kanal_XY ();
-	return;
-}
-
-
 bool dmm_exist (std::string name) //seek for dmm-name in array of installed dmms and set index
 {
 	int i;
@@ -862,7 +1047,6 @@ void select_dmm (int k)
 			dmm_num_bytes[k]->set_value(idmm[i].num_bytes);
 			dmm_num_val[k]->set_value(idmm[i].num_val);
 			dmm_timeout[k]->set_value(idmm[i].ms_timeout);
-			dmm_mtime->set_range (0.001 * idmm[i].ms_timeout, 3600);
 			dmm_remote_control[k]->set_state(idmm[i].remote_cfg);
 			dmm_remote = dmm_remote_control[k]->get_state ();
 			if (dmm_remote)
@@ -885,10 +1069,82 @@ void select_dmm (int k)
 		}
 	}
 	dmm_serial_options[k]->queue_draw ();	
-
+	
 	return;
 }
 
+//////////////////// Reset options to standard values /////////////////////
+
+void reset_options_diag ()
+{
+	//set standard values
+	std_axcol.set_rgba(0.0,0.0,0.0);
+	std_gridcol.set_rgba(0.5,0.5,0.5);
+	std_bkcol.set_rgba(0.95,0.95,0.94);
+	std_xycol.set_rgba(1.0,0.0,0.0);
+
+	//Colours
+	diag->bkcol_r = std_bkcol.get_red();
+	diag->bkcol_g = std_bkcol.get_green();
+	diag->bkcol_b = std_bkcol.get_blue();
+	diag->axcol_r = std_axcol.get_red();
+	diag->axcol_g = std_axcol.get_green();
+	diag->axcol_b = std_axcol.get_blue();
+	diag->gridcol_r = std_gridcol.get_red();
+	diag->gridcol_g = std_gridcol.get_green();
+	diag->gridcol_b = std_gridcol.get_blue();
+	diag->xycol_r = std_xycol.get_red();
+	diag->xycol_g = std_xycol.get_green();
+	diag->xycol_b = std_xycol.get_blue();
+	//Switches
+	diag->grid = true;
+	diag->autoscale = true;
+	diag->showzero = false;
+	diag->showtitle = true;
+	//Symbols
+	diag->mw_symbol = none;
+	diag->symbol_filled = false;
+	//Line style
+	diag->mw_linestyle = solid;
+	//Connection between points
+	diag->mw_line = true;
+	
+	return;
+}
+
+void reset_options_kanal_X ()
+{
+	project->funktion_x = _("Time");
+	dmm[0].dmm_name = "";
+	dmm[0].int_face = "";
+	dmm[0].dmm_typ = TIME;
+	
+	return;
+}
+
+void reset_options_kanal_Y ()
+{
+	dmm[1].dmm_name = "";
+	dmm[1].int_face = "";
+	dmm[1].dmm_typ = DMM;
+	dmm[1].dmm_baud = LibSerial::BaudRate::BAUD_9600;
+	dmm[1].dmm_charsize = LibSerial::CharacterSize::CHAR_SIZE_7;
+	dmm[1].dmm_flowcontrol = LibSerial::FlowControl::FLOW_CONTROL_NONE;
+	dmm[1].dmm_stopbits = LibSerial::StopBits::STOP_BITS_2;
+	dmm[1].dmm_parity = LibSerial::Parity::PARITY_NONE;
+	dmm[1].dmm_polling = true;
+	dmm[1].scpi = false;
+	dmm[1].num_bytes = 0;
+	dmm[1].num_val = 1;
+	dmm[1].ms_timeout = 100;
+	dmm[1].m_funkt = _("DC Voltage");
+	dmm[1].m_range = "2 V";
+	diag->mtime = 1000;
+	
+	return;
+}
+
+
 
 ///////////////// Save DMM Settings ////////////////////////////
 void save_dmm_options(int k)	
@@ -1058,8 +1314,6 @@ void load_dmm_options(int k)
 			dmm_Temp[k]->append (ctrl_str);
 			dmm_Temp[k]->set_active_text (ctrl_str);
 		}			
-		dmm_mtime->set_range (0.001 * dmm_timeout[1]->get_value(), 3600);
-		dmm_mtime->queue_draw ();
 		dmm_serial_options[k]->queue_draw ();
 		
 		dmm_open_file.close();
